@@ -2,4 +2,5 @@ utils::globalVariables(c("AE_ONSET_DT_INT", "AE_SEV_GD", "AE_VERBATIM_TRM_TXT",
                          "Ovar", "PARTIC_ENROL_DT_INT", "PT_ELIG_IND_3", "Subject", "Variable", "ae",
                          "ae_category", "ae_detail", "ae_grade_code_dyn_std", "anova", "as.formula", "binomial",
                          "cl", "desc", "drug1_ae", "gender_code", "group", "ind", "indH", "indH_per", "instance", "join",
-                         "label", "median", "na.fail", "stopCluster", "time_max", "time_median", "time_min", "where"))
\ No newline at end of file
+                         "label", "median", "na.fail", "stopCluster", "time_max", "time_median", "time_min", "where",
+                         "ID", "est", "term", "lower", "upper", "significance", "model1", "reorder"))
\ No newline at end of file
